@@ -38,19 +38,25 @@ def create_credential_resolver(session):
     credentials.
 
     """
-    profile_name = session.get_config_variable('profile') or 'default'
+    profile_name = session.get_config_variable('profile')
     credential_file = session.get_config_variable('credentials_file')
     config_file = session.get_config_variable('config_file')
     metadata_timeout = session.get_config_variable('metadata_service_timeout')
     num_attempts = session.get_config_variable('metadata_service_num_attempts')
-    providers = [
-        EnvProvider(),
+    providers = []
+    if profile_name is None:
+        providers += [
+            EnvProvider(),
+        ]
+        profile_name = 'default'
+
+    providers += [
+        # The new config file has precedence over the legacy
+        # config file.
         SharedCredentialProvider(
             creds_filename=credential_file,
             profile_name=profile_name
         ),
-        # The new config file has precedence over the legacy
-        # config file.
         ConfigProvider(config_filename=config_file, profile_name=profile_name),
         OriginalEC2Provider(),
         BotoProvider(),
