@@ -600,6 +600,11 @@ def create_env(app_name, env_name, region, cname, solution_stack, tier, itype,
                                                         current_environments)
                     env_name = io.prompt_for_environment_name(
                         default_name=unique_name)
+                elif e.message == responses['app.notexists'].replace(
+                        '{app-name}', '\'' + app_name + '\''):
+                    # App doesnt exist, must be a new region.
+                    ## Lets create the app in the region
+                    create_app(app_name, region)
                 else:
                     raise
             else:
@@ -1201,6 +1206,8 @@ def get_solution_stack(solution_string, region):
 
     # No exact match, check for versions
     string = solution_string.replace('-', ' ')
+    # put dash back in preconfigured types
+    string = re.sub('preconfigured\\s+docker', 'preconfigured - docker', string)
     string = re.sub(r'([a-z])([0-9])', '\\1 \\2', string)
     stacks = [x for x in solution_stacks if x.version.lower() == string]
 
