@@ -14,6 +14,7 @@
 from cement.utils.misc import minimal_logger
 
 from ..lib import aws
+from ..objects.exceptions import ServiceError, AlreadyExistsError
 
 LOG = minimal_logger(__name__)
 
@@ -39,4 +40,18 @@ def get_instance_profile_names(region=None):
     for profile in profiles:
         lst.append(profile['InstanceProfileName'])
 
-    return lst
\ No newline at end of file
+    return lst
+
+
+def add_role_to_profile(profile, role, region=None):
+    _make_api_call('add-role-to-instance-profile',
+                   instance_profile_name=profile,
+                   role_name=role,
+                   region=region)
+
+
+def create_role(role, document, region=None):
+    _make_api_call('create-role',
+                   role_name=role,
+                   assume_role_policy_document=document,
+                   region=region)
\ No newline at end of file
